@@ -1,5 +1,5 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
-# Copyright 2019-2020 Hewlett Packard Enterprise Development LP
+# Copyright 2019-2021 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -41,18 +41,109 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
         self.assertEqual(
             [{'step': 'create_configuration',
               'interface': 'raid',
-              'priority': 0},
+              'priority': 0,
+              'reboot_requested': False},
              {'step': 'delete_configuration',
               'interface': 'raid',
-              'priority': 0},
+              'priority': 0,
+              'reboot_requested': False},
              {'step': 'erase_devices',
               'interface': 'deploy',
-              'priority': 0},
+              'priority': 0,
+              'reboot_requested': False},
              {'step': 'update_firmware_sum',
               'interface': 'management',
-              'priority': 0}],
+              'priority': 0,
+              'reboot_requested': False}],
             self.hardware_manager.get_clean_steps("", ""))
 
+    def test_get_deploy_steps(self):
+        self.assertEqual(
+            [{
+                'step': 'apply_configuration',
+                'interface': 'raid',
+                'priority': 0,
+                'reboot_requested': False,
+                'argsinfo': (
+                    hardware_manager._RAID_APPLY_CONFIGURATION_ARGSINFO),
+            },
+                {
+                'step': 'flash_firmware_sum',
+                'interface': 'management',
+                'priority': 0,
+                'reboot_requested': False,
+                'argsinfo': (
+                    hardware_manager._FIRMWARE_UPDATE_SUM_ARGSINFO),
+            }],
+            self.hardware_manager.get_deploy_steps("", ""))
+
+    @mock.patch.object(hardware_manager.SDFlexHardwareManager,
+                       '_create_raid_volumes')
+    @mock.patch.object(hardware_manager.SDFlexHardwareManager,
+                       'delete_configuration')
+    def test_apply_configuration_not_delete(self, delete_mock, create_mock):
+        raid_config = {
+            'logical_disks': [{
+                'size_gb': 100,
+                'raid_level': 1,
+                'physical_disks': [
+                    '5I:0:1',
+                    '5I:0:2'],
+                'controller': 'MSCC SmartRAID controller'
+            },
+            ]
+        }
+        create_mock.return_value = raid_config
+        manager = self.hardware_manager
+        ret = manager.apply_configuration({}, {}, raid_config,
+                                          delete_existing=False)
+        delete_mock.assert_not_called()
+        self.assertEqual(raid_config, ret)
+
+    @mock.patch.object(hardware_manager.SDFlexHardwareManager,
+                       '_create_raid_volumes')
+    @mock.patch.object(hardware_manager.SDFlexHardwareManager,
+                       'delete_configuration')
+    def test_apply_configuration_delete(self, delete_mock, create_mock):
+        raid_config = {
+            'logical_disks': [{
+                'size_gb': 100,
+                'raid_level': 1,
+                'physical_disks': [
+                    '5I:0:1',
+                    '5I:0:2'],
+                'controller': 'MSCC SmartRAID controller'
+            }]
+        }
+        create_mock.return_value = raid_config
+        manager = self.hardware_manager
+        ret = manager.apply_configuration({}, {}, raid_config,
+                                          delete_existing=True)
+        delete_mock.assert_called()
+        self.assertEqual(raid_config, ret)
+
+    @mock.patch.object(hardware_manager.SDFlexHardwareManager,
+                       '_create_raid_volumes')
+    @mock.patch.object(hardware_manager.SDFlexHardwareManager,
+                       'delete_configuration')
+    def test_apply_configuration_delete_default(self, delete_mock,
+                                                create_mock):
+        raid_config = {
+            'logical_disks': [{
+                'size_gb': 100,
+                'raid_level': 1,
+                'physical_disks': [
+                    '5I:0:1',
+                    '5I:0:2'],
+                'controller': 'MSCC SmartRAID controller'
+            }]
+        }
+        create_mock.return_value = raid_config
+        manager = self.hardware_manager
+        ret = manager.apply_configuration({}, {}, raid_config)
+        delete_mock.assert_called()
+        self.assertEqual(raid_config, ret)
+
     @mock.patch.object(os.path, 'exists')
     def test_is_ssacli_present(self, os_path_mock):
         manager = self.hardware_manager
@@ -139,12 +230,37 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
         ret = manager._is_ssa_ctrl_present()
         self.assertEqual(False, ret)
 
+    def test_create_configuration_no_raid_config(self):
+        node = {'target_raid_config': {}}
+        manager = self.hardware_manager
+        ret = manager.create_configuration(node, {})
+        self.assertEqual({}, ret)
+
+    @mock.patch.object(hardware_manager.SDFlexHardwareManager,
+                       '_create_raid_volumes')
+    def test_create_configuration_raid_config(self, create_mock):
+        target_raid_config = {
+            'logical_disks': [{
+                'size_gb': 100,
+                'raid_level': 1,
+                'physical_disks': [
+                    '5I:0:1',
+                    '5I:0:2'],
+                'controller': 'MSCC SmartRAID controller'
+            }]
+        }
+        node = {'target_raid_config': target_raid_config}
+        create_mock.return_value = target_raid_config
+        manager = self.hardware_manager
+        ret = manager.create_configuration(node, {})
+        self.assertEqual(target_raid_config, ret)
+
     @mock.patch.object(hpssa_manager, 'create_configuration')
     @mock.patch.object(hardware_manager.SDFlexHardwareManager,
                        '_is_ssa_ctrl_present')
     @mock.patch.object(hardware_manager.SDFlexHardwareManager,
                        '_is_storcli_ctrl_present')
-    def test_create_configuration_invalid_controller(
+    def test__create_raid_volumes_invalid_controller(
             self, storcli_ctrl_present, ssa_ctrl_present, hpssa_create_mock):
         ssa_ctrl_present.return_value = True
         storcli_ctrl_present.return_value = True
@@ -153,8 +269,7 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
                                "controller": 'invalid ctrl',
                                "physical_disks": ['252:0']}]}
         manager = self.hardware_manager
-        node = {'target_raid_config': raid_config}
-        ret = manager.create_configuration(node, [])
+        ret = manager._create_raid_volumes(raid_config)
         self.assertEqual({'logical_disks': []}, ret)
 
     @mock.patch.object(hpssa_manager, 'create_configuration')
@@ -162,14 +277,14 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
                        '_is_ssa_ctrl_present')
     @mock.patch.object(hardware_manager.SDFlexHardwareManager,
                        '_is_storcli_ctrl_present')
-    def test_create_configuration_ssa(self, storcli_ctrl_present,
+    def test__create_raid_volumes_ssa(self, storcli_ctrl_present,
                                       ssa_ctrl_present, hpssa_create_mock):
         ssa_ctrl_present.return_value = True
         storcli_ctrl_present.return_value = False
         hpssa_create_mock.return_value = 'current-config'
         manager = self.hardware_manager
-        node = {'target_raid_config': {'foo': 'bar'}}
-        ret = manager.create_configuration(node, [])
+        target_raid_config = {'foo': 'bar'}
+        ret = manager._create_raid_volumes(target_raid_config)
         hpssa_create_mock.assert_called_once_with(raid_config={'foo': 'bar'})
         self.assertEqual('current-config', ret)
 
@@ -178,7 +293,7 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
                        '_is_ssa_ctrl_present')
     @mock.patch.object(hardware_manager.SDFlexHardwareManager,
                        '_is_storcli_ctrl_present')
-    def test_create_configuration_ssa_controller(self, storcli_ctrl_present,
+    def test__create_raid_volumes_ssa_controller(self, storcli_ctrl_present,
                                                  ssa_ctrl_present,
                                                  hpssa_create_mock):
         ssa_ctrl_present.return_value = True
@@ -189,8 +304,7 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
                                "controller": 'MSCC SmartRAID',
                                "physical_disks": ['252:0']}]}
         manager = self.hardware_manager
-        node = {'target_raid_config': raid_config}
-        ret = manager.create_configuration(node, [])
+        ret = manager._create_raid_volumes(raid_config)
         hpssa_create_mock.assert_called_once_with(raid_config=raid_config)
         self.assertEqual('current-config', ret)
 
@@ -199,15 +313,15 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
                        '_is_ssa_ctrl_present')
     @mock.patch.object(hardware_manager.SDFlexHardwareManager,
                        '_is_storcli_ctrl_present')
-    def test_create_configuration_storcli(self, storcli_ctrl_present,
+    def test__create_raid_volumes_storcli(self, storcli_ctrl_present,
                                           ssa_ctrl_present,
                                           storcli_create_mock):
         ssa_ctrl_present.return_value = False
         storcli_ctrl_present.return_value = True
         storcli_create_mock.return_value = 'current-config'
         manager = self.hardware_manager
-        node = {'target_raid_config': {'foo': 'bar'}}
-        ret = manager.create_configuration(node, [])
+        target_raid_config = {'foo': 'bar'}
+        ret = manager._create_raid_volumes(target_raid_config)
         storcli_create_mock.assert_called_once_with(raid_config={'foo': 'bar'})
         self.assertEqual('current-config', ret)
 
@@ -217,7 +331,7 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
                        '_is_ssa_ctrl_present')
     @mock.patch.object(hardware_manager.SDFlexHardwareManager,
                        '_is_storcli_ctrl_present')
-    def test_create_configuration_ssa_storcli(self, storcli_ctrl_present,
+    def test__create_raid_volumes_ssa_storcli(self, storcli_ctrl_present,
                                               ssa_ctrl_present,
                                               storcli_create_mock,
                                               hpssa_create_mock):
@@ -226,15 +340,15 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
         hpssa_create_mock.return_value = {'logical_disks': 'current_config'}
         storcli_create_mock.return_value = {'logical_disks': 'current_config'}
         manager = self.hardware_manager
-        node = {'target_raid_config': {
+        target_raid_config = {
             "logical_disks": [
                 {"size_gb": 100, "raid_level": '0', "controller": 0,
                  "physical_disks": ['252:0']},
                 {"size_gb": 'MAX', "raid_level": '0'},
                 {"size_gb": 100, "raid_level": '0',
                  "controller": 'MSCC SmartRAID',
-                 "physical_disks": ['252:2']}]}}
-        ret = manager.create_configuration(node, [])
+                 "physical_disks": ['252:2']}]}
+        ret = manager._create_raid_volumes(target_raid_config)
         storcli_create_mock.assert_called_once_with(raid_config={
             "logical_disks": [{"size_gb": 100, "raid_level": '0',
                                "controller": 0, "physical_disks": ['252:0']}]})
@@ -249,15 +363,15 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
                        '_is_ssa_ctrl_present')
     @mock.patch.object(hardware_manager.SDFlexHardwareManager,
                        '_is_storcli_ctrl_present')
-    def test_create_configuration_no_controller(self, storcli_ctrl_present,
+    def test__create_raid_volumes_no_controller(self, storcli_ctrl_present,
                                                 ssa_ctrl_present):
         ssa_ctrl_present.return_value = False
         storcli_ctrl_present.return_value = False
         manager = self.hardware_manager
-        node = {'target_raid_config': {
+        target_raid_config = {
             "logical_disks": [{"size_gb": 100, "raid_level": '0',
-                "controller": 0, "physical_disks": ['252:0']}]}}
-        ret = manager.create_configuration(node, [])
+                               "controller": 0, "physical_disks": ['252:0']}]}
+        ret = manager._create_raid_volumes(target_raid_config)
         self.assertEqual(ret, None)
 
     @mock.patch.object(hpssa_manager, 'delete_configuration')
@@ -376,7 +490,24 @@ class SDFlexHardwareManagerTestCase(testtools.TestCase):
     @mock.patch.object(sum_controller, 'update_firmware')
     def test_update_firmware_sum(self, update_mock):
         update_mock.return_value = "log files"
-        node = {'foo': 'bar'}
+        url = 'http://1.2.3.4/SPP.iso'
+        checksum = '1234567890'
+        clean_step = {
+            'interface': 'management',
+            'step': 'update_firmware_sum',
+            'args': {'url': url,
+                     'checksum': checksum}}
+        node = {'clean_step': clean_step}
         ret = self.hardware_manager.update_firmware_sum(node, "")
-        update_mock.assert_called_once_with(node)
+        update_mock.assert_called_once_with(node, url, checksum)
+        self.assertEqual('log files', ret)
+
+    @mock.patch.object(sum_controller, 'update_firmware')
+    def test_flash_firmware_sum(self, update_mock):
+        update_mock.return_value = "log files"
+        url = 'http://1.2.3.4/SPP.iso'
+        checksum = '1234567890'
+        node = {'foo': 'bar'}
+        ret = self.hardware_manager.flash_firmware_sum(node, "", url, checksum)
+        update_mock.assert_called_once_with(node, url, checksum)
         self.assertEqual('log files', ret)
