@@ -1,4 +1,4 @@
-# Copyright 2019-2021 Hewlett Packard Enterprise Development LP
+# Copyright 2019-2022 Hewlett Packard Enterprise Development LP
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -203,7 +203,7 @@ class RedfishOperationsTestCase(testtools.TestCase):
     def test_get_pending_bios_settings(self, get_system_mock):
         with open('sdflexutils/tests/unit/redfish/json_samples/'
                   'pending_bios.json', 'r') as f:
-            jsonval = json.loads(f.read()).get("Default")
+            jsonval = json.loads(f.read())
         get_system_mock.return_value.bios.pending_attributes = jsonval
         expected = {'BootSlots': "3,5", "HThread": "on", "RASMode": "on",
                     'UrlBootFile': 'tftp://1.2.3.4/tftp/bootx.efi',
@@ -215,7 +215,7 @@ class RedfishOperationsTestCase(testtools.TestCase):
     def test_get_pending_bios_settings_allow_all(self, get_system_mock):
         with open('sdflexutils/tests/unit/redfish/'
                   'json_samples/pending_bios.json', 'r') as f:
-            jsonval = json.loads(f.read()).get("Default")
+            jsonval = json.loads(f.read())
         get_system_mock.return_value.bios.pending_attributes = jsonval
         expected = {'RASMode': 'on',
                     'BootSlots': '3,5', 'HThread': 'on',
@@ -236,7 +236,7 @@ class RedfishOperationsTestCase(testtools.TestCase):
     def test_set_bios_settings(self, get_system_mock):
         with open('sdflexutils/tests/unit/redfish/json_samples/'
                   'pending_bios.json', 'r') as f:
-            jsonval = json.loads(f.read()).get("Default")
+            jsonval = json.loads(f.read())
         get_system_mock.return_value.bios.pending_attributes = jsonval
         data = {'RASMode': 'on', 'BootSlots': '3,5', 'HThread': 'on',
                 'UrlBootFile': u'tftp://1.2.3.4/tftp/bootx.efi',
@@ -337,14 +337,6 @@ class RedfishOperationsTestCase(testtools.TestCase):
                           self.sdflex_client.enable_vmedia,
                           'some-non-boolean')
 
-    def test_validate_vmedia_device(self):
-        device = sys_cons.VIRTUALMEDIA_DEVICE0
-        self.sdflex_client.validate_vmedia_device(device)
-
-    def test_validate_vmedia_invalid_device(self):
-        self.assertRaises(exception.SDFlexError,
-                          self.sdflex_client.validate_vmedia_device, 'cd2')
-
     @mock.patch.object(redfish.RedfishOperations, 'eject_vmedia')
     def test_eject_vmedia(self, eject_mock):
         eject_mock.return_value = None
@@ -358,7 +350,7 @@ class RedfishOperationsTestCase(testtools.TestCase):
         self.sdflex_client.eject_vmedia.assert_called_once_with('cd0')
 
     def test_eject_vmedia_invalid_device(self):
-        self.assertRaises(exception.SDFlexError,
+        self.assertRaises(exception.InvalidInputError,
                           self.sdflex_client.eject_vmedia, 'cd2')
 
     @mock.patch.object(redfish.RedfishOperations, 'get_vmedia_status')
@@ -400,7 +392,7 @@ class RedfishOperationsTestCase(testtools.TestCase):
 
     def test_insert_vmedia_invalid_device(self):
         url = "http://1.2.3.4:5678/xyz.iso"
-        self.assertRaises(exception.SDFlexError,
+        self.assertRaises(exception.InvalidInputError,
                           self.sdflex_client.insert_vmedia, url, 'device1232',
                           {'remote_image_user_name': 'guest',
                            'remote_image_user_password': 'guest',
@@ -434,3 +426,11 @@ class RedfishOperationsTestCase(testtools.TestCase):
         self.assertRaises(exception.SDFlexError,
                           self.sdflex_client.set_http_boot_uri,
                           'some-non-url')
+
+    def test_get_product_name(self):
+        sushy_system_mock = self.sushy.get_system.return_value
+        type(sushy_system_mock).model = mock.PropertyMock(
+            return_value='Superdome Flex')
+        actual_model_data = self.sdflex_client.get_product_name()
+        expected = 'Superdome Flex'
+        self.assertEqual(expected, actual_model_data)
